Learn R Programming

ngboostForecast (version 0.1.1)

Scores: Select a rule to compare probabilistic predictions to the observed data.

Description

Select a rule to compare probabilistic predictions to the observed data. A score from ngboost.scores, e.g. LogScore.

Usage

Scores(score = c("LogScore", "CRPS", "CRPScore", "MLE"))

Value

A score class from ngboost.scores

Arguments

score

A string. can be one of the following:

  • LogScore : Generic class for the log scoring rule.

  • CRPS : Generic class for the continuous ranked probability scoring rule.

  • CRPScore : Generic class for the continuous ranked probability scoring rule.

  • MLE : Generic class for the log scoring rule.

Author

Resul Akay