Learn R Programming

ngboostForecast (version 0.1.1)

seatbelts: Road Casualties in Great Britain 1969-84

Description

The Seatbelts dataset from the datasets package.

Usage

seatbelts

Arguments

Format

An object of class mts (inherits from ts) with 192 rows and 8 columns.

References

Harvey, A. C. and Durbin, J. (1986). The effects of seat belt legislation on British road casualties: A case study in structural time series modelling. Journal of the Royal Statistical Society series A, 149, 187–227.