Select a rule to compare probabilistic predictions to the observed data. A score from ngboost.scores, e.g. LogScore.
Scores(score = c("LogScore", "CRPS", "CRPScore", "MLE"))A score class from ngboost.scores
A string. can be one of the following:
LogScore : Generic class for the log scoring rule.
CRPS : Generic class for the continuous ranked probability scoring rule.
CRPScore : Generic class for the continuous ranked probability scoring rule.
MLE : Generic class for the log scoring rule.
Resul Akay